==> haskell-monads-tf-0.2.0.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monads-tf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monads-tf
version:              0.2.0.0
visibility:           public
id:                   monads-tf-0.2.0.0-7dGyMIwSgf1BdTcNQQlKyY
key:                  monads-tf-0.2.0.0-7dGyMIwSgf1BdTcNQQlKyY
license:              BSD-3-Clause
maintainer:
    Ross Paterson <ross@soi.city.ac.uk>,
    Chris Martin <chris@typeclasses.com>

author:               Andy Gill
homepage:             https://github.com/typeclasses/monads-tf
synopsis:             Monad classes, using type families
description:
    Monad classes using type families, with instances for
    various monad transformers.

category:             Control
abi:                  cd0186c600eb26a86c7a3aabdd9dfaa9
exposed:              True
exposed-modules:
    Control.Monad.Cont Control.Monad.Cont.Class Control.Monad.Error
    Control.Monad.Error.Class Control.Monad.Except
    Control.Monad.Except.Class Control.Monad.Identity
    Control.Monad.List Control.Monad.RWS Control.Monad.RWS.Class
    Control.Monad.RWS.Lazy Control.Monad.RWS.Strict
    Control.Monad.Reader Control.Monad.Reader.Class Control.Monad.State
    Control.Monad.State.Class Control.Monad.State.Lazy
    Control.Monad.State.Strict Control.Monad.Trans Control.Monad.Writer
    Control.Monad.Writer.Class Control.Monad.Writer.Lazy
    Control.Monad.Writer.Strict

import-dirs:          /usr/lib/ghc-9.4.8/site-local/monads-tf-0.2.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/monads-tf-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/monads-tf-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monads-tf
hs-libraries:         HSmonads-tf-0.2.0.0-7dGyMIwSgf1BdTcNQQlKyY
depends:              base-4.17.2.1 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-monads-tf/html/monads-tf.haddock
haddock-html:         /usr/share/doc/haskell-monads-tf/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monads-tf-0.2.1.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monads-tf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monads-tf
version:              0.2.1.0
visibility:           public
id:                   monads-tf-0.2.1.0-Djl5xso7C3z1riohEa1IpN
key:                  monads-tf-0.2.1.0-Djl5xso7C3z1riohEa1IpN
license:              BSD-3-Clause
maintainer:
    Ross Paterson <ross@soi.city.ac.uk>,
    Chris Martin <chris@typeclasses.com>

author:               Andy Gill
homepage:             https://github.com/typeclasses/monads-tf
synopsis:             Monad classes, using type families
description:
    Monad classes using type families, with instances for
    various monad transformers.

category:             Control
abi:                  da389198ff3ae987468d1323361c7f54
exposed:              True
exposed-modules:
    Control.Monad.Cont Control.Monad.Cont.Class Control.Monad.Error
    Control.Monad.Error.Class Control.Monad.Except
    Control.Monad.Except.Class Control.Monad.Identity
    Control.Monad.List Control.Monad.RWS Control.Monad.RWS.Class
    Control.Monad.RWS.Lazy Control.Monad.RWS.Strict
    Control.Monad.Reader Control.Monad.Reader.Class Control.Monad.State
    Control.Monad.State.Class Control.Monad.State.Lazy
    Control.Monad.State.Strict Control.Monad.Trans Control.Monad.Writer
    Control.Monad.Writer.Class Control.Monad.Writer.Lazy
    Control.Monad.Writer.Strict

import-dirs:          /usr/lib/ghc-9.4.8/site-local/monads-tf-0.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/monads-tf-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/monads-tf-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monads-tf
hs-libraries:         HSmonads-tf-0.2.1.0-Djl5xso7C3z1riohEa1IpN
depends:              base-4.17.2.1 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-monads-tf/html/monads-tf.haddock
haddock-html:         /usr/share/doc/haskell-monads-tf/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
